#! /bin/sh
### BEGIN INIT INFO
# Provides:          swapon
# Required-Start:    $remote_fs $all
# Required-Stop:
# Default-Start:     2 3 4 5
# Default-Stop:
# Short-Description: Enable the swap after a short delay; not during bootup
### END INIT INFO


PATH=/sbin:/usr/sbin:/bin:/usr/bin

. /lib/init/vars.sh
. /lib/lsb/init-functions

case "$1" in
    start)
        start-stop-daemon --start --background --exec /etc/init.d/mountswap.sh -- background
        ;;
    background)
        sleep 120 # probably enough time for desktop login

        #
        # Execute swapon command again, in case we want to swap to
        # a file on a now mounted filesystem.
        #
        # Ignore 255 status due to swap already being enabled
        #
        if [ "$NOSWAP" = yes ]
        then
            [ "$VERBOSE" = no ] || log_warning_msg "Not activating swap as requested via bootoption noswap."
        else
            if [ "$VERBOSE" = no ]
            then
                log_action_begin_msg "Activating swapfile swap"
                swapon -a -e 2>/dev/null || : # Stifle "Device or resource busy"
                log_action_end_msg 0
            else
                log_daemon_msg "Will now activate swapfile swap"
                swapon -a -e -v
                log_action_end_msg $?
            fi
        fi
    ;;
    restart|reload|force-reload)
        echo "Error: argument '$1' not supported" >&2
        exit 3
        ;;
    stop)
        swapoff -a >/dev/null 2>&1
        ;;
    *)
        echo "Usage: $0 start|stop" >&2
        exit 3
        ;;
esac
